Edi.X12.Hipaa.R5010.Segments.BeginningOfHierarchicalTransaction (EDI X12 v0.1.4)
View SourceBHT - Beginning of Hierarchical Transaction
To define the business hierarchical structure of the transaction set and identify the business application purpose and reference data, i.e., number, date, and time
Summary
Types
@type t() :: %Edi.X12.Hipaa.R5010.Segments.BeginningOfHierarchicalTransaction{ date: nil | Date.t(), hierarchical_structure_code: Edi.X12.Identifier.t(), reference_identification: nil | binary(), time: nil | Time.t(), transaction_set_purpose_code: Edi.X12.Identifier.t(), transaction_type_code: nil | Edi.X12.Identifier.t() }
Functions
@spec parse(binary()) :: {:ok, t()} | {:error, binary()}
@spec parse(keyword() | map()) :: {:ok, t()} | {:error, binary()}
Convert the list into a struct.
Examples
iex> parse(elem_1: "Y", elem_2: "ZZ")
{:ok, %Struct{elem_1: "Y", elem_2: "ZZ"}}
Convert the list into a struct.
Examples
iex> parse!(elem_1: "Y", elem_2: "ZZ")
%Struct{
elem_1: "Y",
elem_2: "ZZ"
}